# `dessicate`: A library to stay DRY.
> **Dessiccate** (*verb*): remove the moisture from (something); cause to become completely dry. Also, **Dry** (*adj*): without moisture. Also, an acronym for **DON'T REPEAT YOURSELF**.


This project was started to house functions the author uses a lot so he doesn't have to writ them over and over again. I hope you find some of them useful!

## Install

`pip install dessiccate`
